==> sigutils-2.4.6.tar.gz: sigutils-2.4.6/SigUtils/formatastring.py <==
# -*- coding: iso-8859-1 -*-
__Autor__ = "Luiz Fernando"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.siginformatica.com.br"
__Versao__ = "1.04"
__DataAlteracao__ = "19/08/2011"
import sys
if __name__ == '__main__':
    try:
        if sys.argv[1] == '-9':
            print('formatastring.py\tVersao:' + __Versao__ + '\tData:'+ __DataAlteracao__) + '\tformatar e alinhar strings '
        else:
            print('\n\nformatastring.py - formatar e alinhar strings \n'
                   +'Versao: '+ __Versao__ + '\n'
                   +'Data: '+ __DataAlteracao__ + '\n')
    except:
       print('\n\nformatastring.py - formatar e alinhar strings \n'
               +'Versao: '+ __Versao__ + '\n'
               +'Data: '+ __DataAlteracao__ + '\n')

def formataString(valorString, qtdBytes, caracter=' ', alinhamento="D", usaTrim="S", forcado='N'):
    
    """ sintaxe formataString(ValorDaString, QuantidadeDeBytes, CaracterDePreenchimento, Alinhamemnto, usarTrim, forcado)
      
       Esta funcao, formata um string fornecida (ValorDaString), acrescentando o caracter (CaracterDePreenchimento),
       ateh que a string tenha o tamanho (QuantidadeDeBytes).
       O preenchimento acontece conforme o (alinhamento), onde por default, será a direita se nada for especifidado 
       ou se 'alinhamento=D' à esquerda se 'alinhamento=E' ou nas estremidades se 'alinhamento=C'.
       Se usaTrim='S', espacos a esquerda e a direita sao retirados para depois fazer o alinhamento.
       Se forcado='S', caso a string seja maior do que o tamanho a alinhar,
           trunca a direta,
       se forcado='N', caso a string seja maior do que o tamanho a alinhar,
           retorna for -1
    """
    try:
        caracter = caracter[0]
    except:
        caracter = ' '
    valorString = unicode_to_ascii(valorString)

    if str(type(valorString)) == "<type 'unicode'>":
        sStringAFormatar = valorString
    else:
        sStringAFormatar = str(valorString)

      #retira espaco inicial / Final 
    if usaTrim == "S":
        sStringAFormatar = sStringAFormatar.strip()

    if forcado == 'S':
      if len(sStringAFormatar) > qtdBytes:
         sStringAFormatar = sStringAFormatar[0:qtdBytes]

    iTamString=len(sStringAFormatar)
    if iTamString > qtdBytes:
        return "-1"
    if iTamString == qtdBytes:
        return sStringAFormatar
    if alinhamento == 'D':
        sStringAFormatar=sStringAFormatar.ljust(qtdBytes, caracter )
    if alinhamento == 'E':
       sStringAFormatar=sStringAFormatar.rjust(qtdBytes, caracter )
    if alinhamento == "C":
        sStringAFormatar=sStringAFormatar.center(qtdBytes, caracter )

    return sStringAFormatar

def retirarAspas(Texto):
    try:
        Texto1 = str(unicode_to_ascii(Texto))
    except:
        Texto1 = ''
    
    Texto1.replace('"','').replace("'",'')
#    Texto1=''
#    for x in Texto:
#        if x != "'" and x != '"':
#           Texto1=Texto1+x
#        else:
#           Texto1=Texto1+' '
    return Texto1

def center_cab(ljust, center, rjust, width, fillchar=' '):
    dif = 0
    width_div = width /3
    if width_div * 3 < width:
        dif = width - (width_div * 3)
    ljust = ljust.ljust(width_div, fillchar)
    center = center.center(width_div + dif, fillchar)
    rjust = rjust.rjust(width_div, fillchar)
    res = ljust + center + rjust
    return res
   
def unicode_to_ascii(obj):
    """
    Converte texto unicode em ASCII, retirando acentos e caracteres especiais.
    """
    import unicodedata
    #o mtodo s funciona para unicode, ento, se for passado uma string, convertemos para unicode.
    if type(obj) == unicode:
        s = obj
    elif type(obj) == str:
        s = obj.decode('utf-8')
    else:
        s = unicode(obj)
    
    return ''.join((c for c in unicodedata.normalize('NFD', s) if unicodedata.category(c) != 'Mn'))

==> sigutils-3.1.0.tar.gz: sigutils-3.1.0/SigUtils/formatastring.py <==
# -*- coding: iso-8859-1 -*-
__Autor__ = "Luiz Fernando"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.siginformatica.com.br"
__Versao__ = "1.04"
__DataAlteracao__ = "19/08/2011"
import sys
if __name__ == '__main__':
    try:
        if sys.argv[1] == '-9':
            print(('formatastring.py\tVersao:' + __Versao__ + '\tData:'+ __DataAlteracao__) +
                  '\tformatar e alinhar strings ')
        else:
            print(('\n\nformatastring.py - formatar e alinhar strings \n' +'Versao: '+ __Versao__ +
                   '\n' +'Data: '+ __DataAlteracao__ + '\n'))
    except:
       print(('\n\nformatastring.py - formatar e alinhar strings \n' +'Versao: '+ __Versao__ +
              '\n' +'Data: '+ __DataAlteracao__ + '\n'))

def formataString(valorString, qtdBytes, caracter=' ', alinhamento="D", usaTrim="S", forcado='N'):
    
    """ sintaxe formataString(ValorDaString, QuantidadeDeBytes, CaracterDePreenchimento, Alinhamemnto, usarTrim, forcado)
      
       Esta funcao, formata um string fornecida (ValorDaString), acrescentando o caracter (CaracterDePreenchimento),
       ateh que a string tenha o tamanho (QuantidadeDeBytes).
       O preenchimento acontece conforme o (alinhamento), onde por default, será a direita se nada for especifidado 
       ou se 'alinhamento=D' à esquerda se 'alinhamento=E' ou nas estremidades se 'alinhamento=C'.
       Se usaTrim='S', espacos a esquerda e a direita sao retirados para depois fazer o alinhamento.
       Se forcado='S', caso a string seja maior do que o tamanho a alinhar,
           trunca a direta,
       se forcado='N', caso a string seja maior do que o tamanho a alinhar,
           retorna for -1
    """
    try:
        caracter = caracter[0]
    except:
        caracter = ' '
    valorString = unicode_to_ascii(valorString)

    if str(type(valorString)) == "<type 'unicode'>":
        sStringAFormatar = valorString
    else:
        sStringAFormatar = str(valorString)

      #retira espaco inicial / Final 
    if usaTrim == "S":
        sStringAFormatar = sStringAFormatar.strip()

    if forcado == 'S':
      if len(sStringAFormatar) > qtdBytes:
         sStringAFormatar = sStringAFormatar[0:qtdBytes]

    iTamString=len(sStringAFormatar)
    if iTamString > qtdBytes:
        return "-1"
    if iTamString == qtdBytes:
        return sStringAFormatar
    if alinhamento == 'D':
        sStringAFormatar=sStringAFormatar.ljust(qtdBytes, caracter )
    if alinhamento == 'E':
       sStringAFormatar=sStringAFormatar.rjust(qtdBytes, caracter )
    if alinhamento == "C":
        sStringAFormatar=sStringAFormatar.center(qtdBytes, caracter )

    return sStringAFormatar

def retirarAspas(Texto):
    try:
        Texto1 = str(unicode_to_ascii(Texto))
    except:
        Texto1 = ''
    
    Texto1.replace('"','').replace("'",'')
#    Texto1=''
#    for x in Texto:
#        if x != "'" and x != '"':
#           Texto1=Texto1+x
#        else:
#           Texto1=Texto1+' '
    return Texto1

def center_cab(ljust, center, rjust, width, fillchar=' '):
    dif = 0
    width_div = width /3
    if width_div * 3 < width:
        dif = width - (width_div * 3)
    ljust = ljust.ljust(width_div, fillchar)
    center = center.center(width_div + dif, fillchar)
    rjust = rjust.rjust(width_div, fillchar)
    res = ljust + center + rjust
    return res
   
def unicode_to_ascii(obj):
    """
    Converte texto unicode em ASCII, retirando acentos e caracteres especiais.
    """
    import unicodedata
    #o mtodo s funciona para unicode, ento, se for passado uma string, convertemos para unicode.
    if type(obj) == str:
        s = obj
    elif type(obj) == str:
        s = obj.decode('utf-8')
    else:
        s = str(obj)
    
    return ''.join((c for c in unicodedata.normalize('NFD', s) if unicodedata.category(c) != 'Mn'))
